@@ -44,12 +44,12 @@
  * -----------------------------------------------------------------*/
 
 
-#define SUNDIALS_VERSION "7.1.1"
+#define SUNDIALS_VERSION "7.2.1"
 #define SUNDIALS_VERSION_MAJOR 7
-#define SUNDIALS_VERSION_MINOR 1
+#define SUNDIALS_VERSION_MINOR 2
 #define SUNDIALS_VERSION_PATCH 1
 #define SUNDIALS_VERSION_LABEL ""
-#define SUNDIALS_GIT_VERSION "v7.1.1"
+#define SUNDIALS_GIT_VERSION "v7.2.1"
 
 
 /* ------------------------------------------------------------------
@@ -106,7 +106,7 @@
 
 /* Build metadata */
 #define SUN_C_COMPILER "GNU"
-#define SUN_C_COMPILER_VERSION "14.1.1"
+#define SUN_C_COMPILER_VERSION "14.2.1"
 #define SUN_C_COMPILER_FLAGS "-march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection         -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -g -ffile-prefix-map=/build/sundials/src=/usr/src/debug/sundials -flto=auto"
 
 #define SUN_CXX_COMPILER ""
@@ -119,8 +119,8 @@
 
 #define SUN_BUILD_TYPE "RelWithDebInfo"
 
-#define SUN_JOB_ID "20240626224216"
-#define SUN_JOB_START_TIME "20240626224216"
+#define SUN_JOB_ID "20241220184033"
+#define SUN_JOB_START_TIME "20241220184033"
 
 #define SUN_TPL_LIST "MPI;OPENMP;KLU;PTHREAD"
 #define SUN_TPL_LIST_SIZE ""
@@ -144,6 +144,9 @@
 /* HYPRE */
 /* #undef SUNDIALS_HYPRE_ENABLED */
 #define SUN_HYPRE_VERSION ""
+#define SUN_HYPRE_VERSION_MAJOR 
+#define SUN_HYPRE_VERSION_MINOR 
+#define SUN_HYPRE_VERSION_PATCH 
 
 /* KLU */
 #define SUNDIALS_KLU_ENABLED
@@ -239,12 +242,12 @@
 /* #undef SUNDIALS_ONEMKL_USE_GETRS_LOOP */
 
 /* SUPERLUMT threading type */
-#define SUNDIALS_SUPERLUMT_THREAD_TYPE ""
+#define SUNDIALS_SUPERLUMT_THREAD_TYPE "PTHREAD"
 
 /* Trilinos with MPI is available, then
  *    #define SUNDIALS_TRILINOS_HAVE_MPI
  */
-/* #undef SUNDIALS_TRILINOS_HAVE_MPI */
+#define SUNDIALS_TRILINOS_HAVE_MPI
 
 
 /* ------------------------------------------------------------------
